@@ -1,5 +1,5 @@
 """This is the "nester.py" module, has a "print_lol" function"""
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     """This function has a parameter, is "the_list", it's any list."""
     for each_item in the_list:
         if isinstance(each_item, list):
